"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _keys = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/object/keys"));

var _webpack = _interopRequireDefault(require("webpack"));

var _path2 = _interopRequireDefault(require("path"));

var _progressBarWebpackPlugin = _interopRequireDefault(require("progress-bar-webpack-plugin"));

var _terserWebpackPlugin = _interopRequireDefault(require("terser-webpack-plugin"));

var _is = _interopRequireDefault(require("./is"));

var _logger = _interopRequireDefault(require("./logger"));

function logTypeError() {
  _logger["default"].fatal("DllPlugin only supply an Array or Object(the value must be an Array) as entry");
}

module.exports = function (options) {
  var config = {};
  var isDebug = options.debug || false;
  var entry = options.entry;
  var _path = options.path;
  var output = {
    path: _path
  };

  if (_is["default"].Array(entry)) {
    output.filename = 'vendor.js';
    output.library = 'vendor_library';
  } else if (_is["default"].Object(entry)) {
    var typeError = false;
    (0, _keys["default"])(entry).forEach(function (key) {
      if (!_is["default"].Array(entry[key])) {
        typeError = true;
      }
    });

    if (typeError) {
      logTypeError();
    } else {
      output.filename = '[name].js';
      output.library = '[name]_library';
    }
  } else {
    logTypeError();
  }

  output.path = _path;
  config.plugins = [new _webpack["default"].DllPlugin({
    path: _path2["default"].join(_path, "".concat(output.filename, ".json")),
    name: output.library // context: _path

  }), new _progressBarWebpackPlugin["default"]({
    format: ' build dll file [:bar] :percent (:elapsed seconds)',
    clear: false,
    width: 60
  })];
  config.entry = entry;
  config.output = output;

  if (!isDebug) {
    config.mode = 'production';
    config.optimization = config.optimization || {};
    config.optimization.minimize = true;
    config.optimization.minimizer = [new _terserWebpackPlugin["default"]()];
  } else {
    config.mode = 'development';
  }

  config.plugins.push(new _webpack["default"].DefinePlugin({
    'process.env.NODE_ENV': isDebug ? '"development"' : '"production"',
    __DEV__: isDebug
  }));
  return config;
};
//# sourceMappingURL=load-dllPlugin-config.js.map