"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _util = require("util");

var _chalk = _interopRequireDefault(require("chalk"));

/**
 * @Author: Zhengfeng.Yao <yzf>
 * @Date:   2017-04-25 16:46:26
 * @Last modified by:   yzf
 * @Last modified time: 2017-04-25 16:47:48
 */
var _require = require('../../package.json'),
    version = _require.version;

var prefix = "[tdtool@".concat(version, "]");

var sep = _chalk["default"].gray('-');

function formatTime(time) {
  return time.toTimeString().replace(/.*(\d{2}:\d{2}:\d{2}).*/, '$1');
}
/**
 * Log a `message` to the console
 *
 * @param {String} message
 */


exports.info = function () {
  for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  var msg = _util.format.apply(_util.format, args);

  var time = new Date();
  console.log(_chalk["default"].cyan("".concat(prefix, "[").concat(formatTime(time), "]")), sep, msg);
};
/**
 * Log an error `message` to the console and not exit
 *
 * @param {String} message
 */


exports.error = function (message) {
  if (message instanceof Error) {
    message = message.message.trim();
  } // eslint-disable-next-line


  var msg = _util.format.apply(_util.format, arguments);

  var time = new Date();
  console.error(_chalk["default"].red("".concat(prefix, "[").concat(formatTime(time), "]")), sep, msg);
};
/**
 * Log an error `message` to the console and exit
 *
 * @param {String} message
 */


exports.fatal = function (msg) {
  exports.error(msg);

  if (process.env.NODE_ENV === 'test') {
    throw new Error('exit');
  } else {
    process.exit(1);
  }
};
/**
 * Log a warning `message` to the console
 *
 * @param {String} message
 */


exports.warn = function () {
  for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
    args[_key2] = arguments[_key2];
  }

  var msg = _util.format.apply(_util.format, args);

  var time = new Date();
  console.log(_chalk["default"].yellow("".concat(prefix, "[").concat(formatTime(time), "]")), sep, msg);
};
/**
 * Log a success `message` to the console
 *
 * @param {String} message
 */


exports.success = function () {
  for (var _len3 = arguments.length, args = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
    args[_key3] = arguments[_key3];
  }

  var msg = _util.format.apply(_util.format, args);

  var time = new Date();
  console.log(_chalk["default"].green("".concat(prefix, "[").concat(formatTime(time), "]")), sep, msg);
};
//# sourceMappingURL=logger.js.map